@@ -1,4 +1,4 @@
-/* $Id: xfce-desktopentry.c,v 1.14 2004/11/11 12:55:43 jasper Exp $ */
+/* $Id: xfce-desktopentry.c 914 2005-01-17 01:52:30Z kelnos $ */
 /*-
  * Copyright (C) 2004 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -312,7 +312,7 @@ entry_parse (XfceDesktopEntry * desktop_entry)
 
 	for (i = 0; i < desktop_entry->priv->num_entries; ++i, ++entry)
 	{
-	    if (strcmp (key, entry->key) == 0)
+	    if (key && entry->key && strcmp (key, entry->key) == 0)
 	    {
 		if (current_locale && locale)
 		{
